@@ -83,89 +83,18 @@ class _LoggerPickler(jsonpickle.pickler.Pickler):
 
 class Logger(metaclass=_Singleton):
     """
-    ¬
+    Creates a singleton instance of the logger.
 
-    --> Log Tags
+    Set these properties prior to starting the logger if the default is undesired.
 
-    Log tags are a conceptual representation of how the program can be divided in terms of logging. Common
-    tags are severity tags: info, debug, warning, error, and critical. However, custom tags can be created
-    to represent the logging in more and different ways. Rather than severity tags, tags could alternatively
-    represent the level of code that is performing the log, such as the Data Access Layer vs. a public API
-    layer. Log tags provide a way to tag log messages so they can be more easily filtered when viewing the
-    output.
-
-    To create custom log tags, either import the LogTagTemplate or the LogTags and inherit it in the new
-    custom log tag class. A ``default`` and ``critical`` log tags are required because the logger uses
-    defaults for standard and error logging. The LogTagTemplate does not define any of the required tags,
-    but raises an error when they are not implemented whereas the LogTags does. Here is an example:
-
-        from logger.config import LogTagTemplate, LogTags, LogTag
-
-        # Inheriting from LogTagTemplate requires default and critical tags to be defined.
-        class CustomLogTags1(LogTagTemplate):
-            default = LogTag(
-                name='Standard',
-                value=0,
-                html_color='cyan'
-            )
-
-            test = LogTag(
-                name='Test',
-                value=10,
-                html_color='green'
-            )
-
-            critical = LogTag(
-                name='Critical',
-                value=90,
-                html_color='red'
-            )
-
-        # Inheriting from LogTags doesn't require default and critical tags to be defined.
-        class CustomLogTags2(LogTags):
-            test = LogTag(
-                name='Test',
-                value=10,
-                html_color='green'
-            )
-
-    To use the custom log tags, set the ``log_tags`` to the class that defines them. Using the
-    example above, ``logger.log_tags = CustomLogTags1``. Then ``logger.log(msg, CustomLogTags1.test)``
-    would be legal.
-
-    --> Basic Logging
-
-    There are three basic logging methods: ``log()``, ``log_method()``, and ``log_exception()``.
-
-    ``log()`` simply commits a log message on the fly. The function name is retrieved dynamically.
-    ``log_method()`` should at most rarely be used. It creates a log entry with a given function name.
-    ``log_exception()`` is used to locate the exception in the call stack to log.
-
-    --> Logging Control
-
-    Logging output can be controlled by setting rules once the ``start()`` method is called. These
-    rules are set using the ``set_rule()`` method. These rules control a few factors when logging:
-        a) The mode. There are four modes: current, console, persistence, and all. The console mode
-           only logs to stdout. The persistence mode only logs to the DB log file. All does both. The
-           current mode does not switch the mode when setting the rule.
-        b) The rule. Basic rules are setting a minimum tag value or blacklisting a set of tag names.
-           A custom rule can be supplied as well. This controls what will and won't get logged to
-           reduce noise in the logs.
-        c) Why. This is a message suggesting why the rule was changed. This will always be logged.
-
-    --> Contextual Logging
-
-    Use ``generate()`` as a context manager (i.e. ``with logger.generate('html'):``). Nothing is yielded
-    to the context block. After the context is executed, the logger automatically searches the call stack
-    if an error is raised and logs it. If persistence is enabled, the format generator's ``generate()``
-    method is called to create the log file from the DB file. HTML is the only generator provided, although
-    a custom generator can be created.
-
-    --> Log Wrappers
-
-    There are two log wrappers: wrap_class() and wrap_func(). They log the inputs and outputs of functions.
-    They provided depth to the log output, meaning a hierarchy of logs can be created. Without these methods
-    all logs would be flat and one dimensional. See their docstrings for more details.
+        * ``default_log_tag`` (default: INFO): LogTagType to use in ``log()`` when the log_tag isn't specified.
+        * ``default_exception_tag`` (default: CRITICAL): LogTagType that will be called in ``log_exception()``.
+        * ``date_format`` (default: `%Y/%m/%d %H:%M:%S`): String compatible with Python's strftime.
+        * ``default_rule`` (default: ``lambda x: (False, False)``): Callable function that returns one or two booleans.
+          If one boolean, then both console and persistence apply that value. Otherwise return a boolean in the order
+          of (do not send to console, do not persist).
+        * ``redirect`` (default: None): String path to the text file to create. The path is created if it doesn't exist.
+        * ``add_log_tags()``: Call this method to add custom log tags prior to starting the logger.
     """
 
     CONSOLE_LOCK = threading.Lock()
@@ -176,6 +105,7 @@ class Logger(metaclass=_Singleton):
         self.default_log_tags = DefaultLogTags()
         self.default_log_tag = self.default_log_tags.info
         self.default_exception_tag = self.default_log_tags.critical
+        self._default_rule = lambda x: (False, False)
 
         self._disabled = True
         self._date_format = '%Y/%m/%d %H:%M:%S'
@@ -190,7 +120,6 @@ class Logger(metaclass=_Singleton):
         self._redirect = None
         self._redirect_stream = None
         self._log_tags_locked = False
-        self._default_rule = lambda x: (False, False)
         self.__logs = {}
         self.__loaded_logs = {}
 
@@ -200,6 +129,20 @@ class Logger(metaclass=_Singleton):
         return [v for y in log_tags for k, v in vars(y).items() if isinstance(v, LogTagBase)]
 
     def add_log_tags(self, value):
+        """
+        Appends the log tags to the list of custom log tags. This will fail after the logger has been started.
+        The log tags must be stored in a class like this:
+
+        .. code-block:: python
+
+            class LogTags:
+                some_tag = LogTagTypes.Info(name='Some Tag')
+
+            logger.add_log_tags(LogTags)
+
+        Args:
+            value: A class of Log
+        """
         if self._log_tags_locked and value not in self._other_log_tags:
             raise AssertionError(f'Log tags cannot be added to the logger after '
                                  f'the logger has been started.')
@@ -216,6 +159,14 @@ class Logger(metaclass=_Singleton):
 
     @staticmethod
     def add_cleanup(func, *args, **kwargs):
+        """
+        Add a cleanup action using Python's ``atexit`` module.
+
+        Args:
+            func: Callable function.
+            *args: Function arguments.
+            **kwargs: Function keyword arguments.
+        """
         atexit.register(func, *args, **kwargs)
 
     @property
@@ -227,6 +178,12 @@ class Logger(metaclass=_Singleton):
         self._date_format = format
 
     def get_logs(self):
+        """
+        Use this to get the logs to pass to the HtmlLogGenerator parser. Not required
+        if you are using the ``logger.generate()`` context manager.
+
+        Returns: A dictionary with the log tags, entries, and main thread id.
+        """
         if self.__loaded_logs:
             return self.__loaded_logs
         log_tags = [{
@@ -257,23 +214,29 @@ class Logger(metaclass=_Singleton):
         self._redirect = value
         self._redirect_stream = open(value, 'a+')
 
+    def clear_logs(self):
+        """
+        Clears the log entries.
+        """
+        self.__logs = {}
+
     @contextmanager
     def disabled(self, log_tag: LogTagBase = None, why: str = ''):
         """
         WARNING! This disables all logging in a context. This trumps all rules and modes as no logs
-        will be processed or printed to the console. Use carefully. Useful in contexts of large
-        concurrency and redundant logging. Upon exit of the context the logger will reset to the
-        original state. Upon exit the logger will raise an error if an exceptions were raised in the
-        context and the original state of the logger was enabled. In other words, if the logger was
-        never started with ``start()``, then it will not log the exceptions.
+        will be processed or printed to the console. Use carefully. Upon exit of the context the logger
+        will reset to the original state. Upon exit the logger will raise an error if any exceptions were
+        raised in the context and the original state of the logger was enabled. In other words, if the
+        logger was never started with ``start()``, then it will not log the exceptions.
+
+        .. code-block:: python
 
-        Examples:
             logger = Logger(...)
 
             with logger.disabled(log_tag=log_tags.default, why='Suppressing redundant logs...'):
                 for i in range(5000):
-                    logger.log('I will not be logged at all. Period.')
-            logger.log('I am logged!')
+                    logger.info('I will not be logged at all. Period.')
+            logger.info('I am logged!')
 
         Args:
             log_tag: The log tag that logs why. Defaults to the default tag.
@@ -294,12 +257,27 @@ class Logger(metaclass=_Singleton):
         self.log(msg=f'Re-enabling logging. {why}', log_tag=log_tag, num_prev_callers=num_prev_callers)
 
     def dump(self, path: Union[Path, str]):
+        """
+        Dump the logs to ``path``. This option is still under development. Its intent is to dump
+        logs to a file on disk to free memory. Currently memory isn't freed by default, so use only
+        if you know what you are doing.
+
+        Args:
+            path: Path to the JSON file to dump the logs.
+        """
         path = Path(path) if not isinstance(path, Path) else path
         path.parent.mkdir(parents=True, exist_ok=True)
         with path.open('w') as f:
             json.dump(self.get_logs(), f)
 
     def load(self, json_file):
+        """
+        Loads logs from a JSON file, which would come from ``dump()``. This feature is still
+        under development, so only use if you know what you are doing.
+
+        Args:
+            json_file: Path to the JSON file.
+        """
         path = Path(json_file) if not isinstance(json_file, Path) else json_file
         if not path.exists():
             raise FileNotFoundError(f'Could load logs because the path "{path}" was not found.')
@@ -310,37 +288,30 @@ class Logger(metaclass=_Singleton):
     def generate(self, format_generator: Union[str, Callable], log_file: Union[Path, str],
                  persist: bool = True, **kwargs):
         """
-        Generates logs and optionally generates an output file from the DB log file according
-        to the ``format_generator`` parameter. The ``format_generator`` is either a string
-        that identifies a built-in format generator or a custom generator that is callable.
+        A context manager that generates a log file from the logs persisted in the context using a format
+        generator. The ``format_generator`` currently only supports HTML, but a custom one could be built.
 
-        The only built-in generator is 'html' at this time.
+        A custom log generator must be a class whose __init__ accepts the logs from ``get_logs()`` and
+        must have a ``generate()`` method that accepts the log file path and kwargs. For example
 
-        A custom generator can be used. It must be able to be initialized without parameters
-        and have a ``generate()`` function with at least a ``log_file`` parameter. Optional
-        parameters can be passed to the generator as ``kwargs``. For example:
+        .. code-block:: python
 
-            # Using the built-in HTML generator.
-            with logger.generate('html'):
-                # Do stuff here.
+            class CustomLogGenerator:
+                def __init__(self, logs: dict):
+                    self._log_tags = logs['log_tags']
+                    self._log_entries = logs['log_entries']
+                    self._main_thread_id = logs['main_thread_id']
 
-            # Using a custom generator.
-            class SomeCustomGenerator:
-                def __init__(self):  # No arguments required!
-                    # Initialize stuff here.
-
-                # This method is required!
-                def generate(log_file: str, **kwargs): # log_file required!
-                    # Generate output here.
-
-            with logger.generate(SomeCustomGenerator, custom_kw='Some Custom Variable Value'):
-                # Do stuff here.
+                def generate(log_file: str, **kwargs):
+                    # Define the generation logic here.
+                    pass
 
         Args:
-            format_generator: Either a string for a built-in generator or a callable custom one.
-            log_file:
-            persist:
-            **kwargs: Extra arguments to pass to the generator.
+            format_generator: If a string type then only 'html' is supported, which uses the HtmlLogGenerator
+                              class. Otherwise a custom callable object can be used to generate the logs.
+            log_file: The path to the log file. It is created if it doesn't already exist.
+            persist: If ``True`` then the data is persisted and the output is generated. Otherwise the generator
+                     does not run.
         """
         if self._disabled:
             self.start(persist=persist)
@@ -367,37 +338,76 @@ class Logger(metaclass=_Singleton):
                 self.log_exception()
 
     def debug(self, msg: Any, num_prev_callers: int = 0):
+        """
+        Logs a message with the default DEBUG log tag.
+
+        Args:
+            msg: Log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
+        """
         self.log(msg=msg, log_tag=self.default_log_tags.debug, num_prev_callers=num_prev_callers + 1)
 
     def info(self, msg: Any, num_prev_callers: int = 0):
+        """
+        Logs a message with the default INFO log tag.
+
+        Args:
+            msg: Log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
+        """
         self.log(msg=msg, log_tag=self.default_log_tags.info, num_prev_callers=num_prev_callers + 1)
 
     def warning(self, msg: Any, num_prev_callers: int = 0):
+        """
+        Logs a message with the default WARNING log tag.
+
+        Args:
+            msg: Log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
+        """
         self.log(msg=msg, log_tag=self.default_log_tags.warning, num_prev_callers=num_prev_callers + 1)
 
     def error(self, msg: Any, num_prev_callers: int = 0):
+        """
+        Logs a message with the default ERROR log tag.
+
+        Args:
+            msg: Log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
+        """
         self.log(msg=msg, log_tag=self.default_log_tags.error, num_prev_callers=num_prev_callers + 1)
 
     def critical(self, msg: Any, num_prev_callers: int = 0):
+        """
+        Logs a message with the default CRITICAL log tag.
+
+        Args:
+            msg: Log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
+        """
         self.log(msg=msg, log_tag=self.default_log_tags.critical, num_prev_callers=num_prev_callers + 1)
 
     def log(self, msg: Any, log_tag: LogTagBase = None, num_prev_callers: int = 0):
         """
-        Logs a message if logging is enabled and it satisfies the rule set. The default rule allows
-        all logging. The rule may specify console logging only, persistent logging only, or both.
-
-        ``num_prev_callers`` allows the caller to specify which caller in the call stack should be
-        referenced in the log entry. By default the caller of this method is captured and logged.
-        This is handy to use when the caller of this method doesn't live in a method whose context
-        is helpful to debugging. For example, if A calls B and B calls ``log(..., prev_num_callers=1)``
-        then the message is logged with a reference to the file path, line number, and function name
-        from caller A in relation to the call stack.
+        Logs a message with the ``log_tag`` log tag if given, else the ``default_log_tag``, which, if
+        not explicitly set, defaults to the INFO log tag.
 
         Args:
             msg: Log message.
-            log_tag: The log tag that logs the message. Defaults to the default tag.
-            num_prev_callers: Number of callers in the current call stack previous to the caller of
-                              this method.
+            log_tag: A LogTagType to tag to the log message.
+            num_prev_callers: Number of previous calls in the call stack that identifies the
+                originator of the log message. This should rarely, if ever, be set, but is
+                configurable should a a previous caller be tied to the log message.
         """
         if self._disabled:
             return
@@ -415,8 +425,11 @@ class Logger(metaclass=_Singleton):
 
     def log_exception(self, log_tag: LogTagBase = None):
         """
-        Logs the function name, file path, line number, and exception message if logging is enabled. The
-        log tag used is ``critical``. The log rule is disregarded.
+        Logs an exception using `traceback.format_exc()` with the ``log_tag`` log tag if given, else
+        the ``default_exception_tag``, which, if not explicitly set, defaults to the CRITICAL log tag.
+
+        Args:
+           log_tag: A LogTagType object that suits an exception. If not given
         """
         if self._disabled:
             return
@@ -443,17 +456,15 @@ class Logger(metaclass=_Singleton):
 
     def log_method(self, func: callable, msg: Any, log_tag: LogTagBase = None, returning: bool = False):
         """
-        Similar to ``log()`` with one particular difference. ``log()`` dynamically retrieves the
-        information of the referenced caller using ``num_prev_callers`` whereas ``log_method()``
-        directly uses ``func`` for the name of the function and ``returning`` to decide if the
-        line number referenced is the first or last line of the function. This method should rarely
-        be used. To log a method use ``wrap_func()`` instead as it handles log depth.
+        Logs a call or exit of a method or function with the name of the callable and the given ``msg``
+        with the ``log_tag`` log tag if given, else the ``default_log_tag``, which, if not explicitly set,
+        defaults to the INFO log tag. This is generally not needed and should only be used by ``wrap_func()``.
 
         Args:
-            func: A callable function.
-            msg: Log message.
-            log_tag: The log tag that logs the message. Defaults to the default tag.
-            returning: If ``True``, reference the last line of the method, otherwise the first.
+            func: A callable object.
+            msg: The log message.
+            log_tag: The LogTagType object.
+            returning: If ``True`` gets the last line number of the function instead of the first for the log.
         """
         if self._disabled:
             return
@@ -480,10 +491,20 @@ class Logger(metaclass=_Singleton):
     def rule(self, log_tag: LogTagBase = None, min_level: str = None,
              blacklist_function: Callable[[LogTagBase], Tuple[bool, bool]] = None, why: str = ''):
         """
-        A context manager for `meth:logboss.logger.set_rule`.
+        The context manager equivalent of ``set_rule()``. When the context exits the ``default_log_rule``
+        is applied, which if unset defaults to ``lambda x: (False, False)``, which means there are no
+        restrictions enforced by the rules.
 
-            with logger.rule_context(...):
-                # Code here.
+        Args:
+            log_tag: The LogTagType object.
+            min_level: If a string, must be one of 'debug', 'info', 'warning', 'error', or 'critical', from
+                       which the value of the respective default log tag type is used as a minimum threshold
+                       for a log event to occur. Otherwise it must be an integer.
+            blacklist_function: A custom callable that accepts a single argument (the log tag) and returns
+                       either a single boolean (which applies to both console and persistent modes) or a tuple
+                       of booleans where the first applies to the console and the second to persistence. A
+                       value of ``True`` means the log event will be ignored (hence blacklisted).
+            why: The reason why the rule is being created, which is logged using the ``log_tag``.
         """
         self._set_rule(log_tag=log_tag, min_level=min_level, blacklist_function=blacklist_function,
                        why=why, num_prev_callers=2)
@@ -494,7 +515,9 @@ class Logger(metaclass=_Singleton):
         """
         The log mode can be used to change where the logs are recorded. This is useful for simply
         reducing noise in the log output.
+
         There are four modes: current, console, persistence, and all.
+
             * current: Do not change the mode. Default.
             * console: Change the mode to log to the console only.
             * persistence: Change the mode to log to the SQLite DB file only.
@@ -502,7 +525,7 @@ class Logger(metaclass=_Singleton):
 
         Args:
             mode: One of 'current', 'console', 'persistence', or 'all'. Default is 'current'. Case sensitive.
-            log_tag: The log tag that logs why. Defaults to the default tag.
+            log_tag: The log tag that logs why. Defaults to the default INFO log tag.
             why: A description of why the mode is being set.
         """
         if self._disabled:
@@ -533,42 +556,20 @@ class Logger(metaclass=_Singleton):
                  blacklist_function: Callable[[LogTagBase], Tuple[bool, bool]] = None,
                  reset: bool = False, why: str = ''):
         """
-        Sets a rule that dictates what will and will not get logged, as well as how they are logged.
-
-        The ``min_tag_value`` specifies the minimum tag value that a log tag must have in order to
-        log a message.
-
-        The ``blacklist_tag_names`` specifies a list of tag names that prevent messages from being
-        logged. In other words, a log tag whose name is blacklisted will not log the message.
-
-        The ``blacklist_function`` defines a custom function that blacklist log tags from logging
-        their messages. There is no whitelist option. The function must return a boolean where
-        ``False`` allows a message to be logged.
-
-        The ``reset`` flag resets the log rules to their initial state when the logger was
-        initialized.
-
-        If none of ``min_tag_value``, ``blacklist_tag_names``, ``blacklist_function``, or ``reset`` are
-        specified, then no rules are set to restrict any logging. In other words, all logging in the
-        specified mode is enabled.
-
-        The rule that is set cannot change unless calling `set_rule()` with a log tag value greater than
-        or equal to the log tag used to set the rule in the first place. So:
-
-            logger.set_rule(log_tag=LogTags.with_value_10, min_tag_value=20)  # Honored.
-            logger.log(log_tag=LogTags.with_value_1, ...)  # Not logged.
-            logger.log(log_tag=LogTags.with_value_10, ...)  # Not logged.
-            logger.log(log_tag=LogTags.with_value_20, ...)  # Logged.
-            logger.set_rule(log_tag=LogTags.with_value_5, reset=True)  # Not honored.
-            logger.set_rule(log_tag=LogTags.with_value_15, min_tag_value=20)  # Honored.
+        Sets a rule for blacklisting log messages. This is particularly useful when reducing noise in the
+        log output. Only one of ``min_level``, ``blacklist_function``, or ``reset`` can be specified.
 
         Args:
-            log_tag: The log tag that logs why. Defaults to the default tag.
-            min_level:
-            blacklist_function: Optional. This is evaluate first. If not ``None``, this rule is used.
-            reset: Optional. This is evaluated last. If not ``None``, the rule in the specified mode is reset
-                   to the initial state.
-            why: A description of why the rule is being set.
+            log_tag: The LogTagType object.
+            min_level: If a string, must be one of 'debug', 'info', 'warning', 'error', or 'critical', from
+                       which the value of the respective default log tag type is used as a minimum threshold
+                       for a log event to occur. Otherwise it must be an integer.
+            blacklist_function: A custom callable that accepts a single argument (the log tag) and returns
+                       either a single boolean (which applies to both console and persistent modes) or a tuple
+                       of booleans where the first applies to the console and the second to persistence. A
+                       value of ``True`` means the log event will be ignored (hence blacklisted).
+            reset: If ``True`` then the ``default_log_rule`` is applied.
+            why: The reason why the rule is being created, which is logged using the ``log_tag``.
         """
         return self._set_rule(
             log_tag=log_tag, min_level=min_level, blacklist_function=blacklist_function, reset=reset,
@@ -577,23 +578,15 @@ class Logger(metaclass=_Singleton):
 
     def start(self, persist: bool = False):
         """
-        Starts the logging. By default all logging is disabled. Once this method is called, logging
-        is initialized according to the log path, log tags, and date format set. By default, nothing
-        is set. These variables can be changed throughout the execution of the program, although it
-        is not recommended as the output can produce unexpected results.
+        Starts the logger. If not called, no log events occur. Once the logger is started then the log
+        tags cannot be modified. Also, it is wise to NOT modify the ``redirect``, ``default_log_tag``,
+        ``default_exception_tag``, ``default_log_rule``, or any of the private variables associated to
+        the logger. In general, once the logger is started, then the only calls to the logger should
+        be setting rules/modes and logging messages.
 
-        If nothing is set and this method is called, only stdout is enabled. No logs will persist.
-
-        The ``log_path`` can change throughout the execution of the program given that the file does
-        not already exist (but the parent folder must exist). Once set, call ``start()`` again to
-        reinitialize the DB file.
-
-        The ``log_tags`` can change, although this is dangerous and should not happen. Once this
-        method is called, the DB is initialized with all of the log tag data. If the log tags
-        change during execution of the program and contains tags that did not exist previously,
-        then they will not be included in the output logs.
-
-        The ``date_format`` can change any time as this only affects stdout.
+        Args:
+            persist: If ``True`` the logs will also persist in memory. Otherwise logs are only sent to
+                the console or ``redirect`` path.\
         """
         self._disabled = False
         self._log_tags_locked = True
@@ -617,9 +610,7 @@ class Logger(metaclass=_Singleton):
             func_regex_exclude: A regular expression matching method names that should not be wrapped.
             mask_input_regexes: Passed to ``wrap_func()``.
             mask_output: Passed to ``wrap_func()``.
-            mask_output_regexes: A list of regular expressions of keys whose values ought to be masked in the
-                                 output. This only applies to return values with key/value pair associations.
-                                 Use ``mask_output`` if the output is not a dictionary-like object (such as a string).
+            mask_output_regexes: Passed to ``wrap_func()``..
         """
         log_tag = log_tag or self.default_log_tag
         if isinstance(mask_output_regexes, list):
@@ -660,16 +651,16 @@ class Logger(metaclass=_Singleton):
                   mask_output_regexes: List = None, is_staticmethod: bool = False, is_classmethod: bool = False):
         """
         Wrapper for a function or method. This wrapper performs a few important steps:
-            1. Increases the depth of the call, which controls its relation to all previous and
+            #. Increases the depth of the call, which controls its relation to all previous and
                subsequent logs in the log hierarchy.
-            2. Logs the function's name, inputs, and outputs.
-            3. Catches any exceptions raised by the function and logs them.
-            4. Decreases the depth of the call to return to the original depth of the call hierarchy.
+            #. Logs the function's name, inputs, and outputs.
+            #. Catches any exceptions raised by the function and logs them.
+            #. Decreases the depth of the call to return to the original depth of the call hierarchy.
 
         The depth is the defining marker for the position of a function in the logged hierarchy. Without it,
         all logs would be flat an hard to parse through.
 
-        Example:
+        .. code-block:: python
 
             @logger.wrap_func(
                 log_tag=Tags.SomeTag,
@@ -682,23 +673,23 @@ class Logger(metaclass=_Singleton):
                 return {'API Token': 'xyz'}
 
         * The above example will use the ``Tags.SomeTag`` tag to log the calling and the returning message.
-        * The ``cls`` and ``password`` parameters will be masked. The message will show this:
+        * The ``cls`` and ``password`` parameters will be masked. The message will show this::
 
-          Called do_something
-          Arguments:
-          {
-              "cls": "********",
-              "username": "Admin",
-              "password": "********"
-          }
+              Called do_something
+              Arguments:
+              {
+                  "cls": "********",
+                  "username": "Admin",
+                  "password": "********"
+              }
 
-        * The output is not masked entirely, but the output will be partially masked like this:
+        * The output is not masked entirely, but the output will be partially masked like this::
 
-          do_something returned.
-          Return Values:
-          {
-              "API Token": "********"
-          }
+              do_something returned.
+              Return Values:
+              {
+                  "API Token": "********"
+              }
 
         Args:
             log_tag: The log tag to apply to the input and output log messages.
@@ -706,9 +697,9 @@ class Logger(metaclass=_Singleton):
             mask_output: When ``True`` the entire  output is masked like this: "********".
             mask_output_regexes: A list of regular expressions of keys whose values ought to be masked in the
                                  output. This only applies to return values with key/value pair associations.
-                                 Use ``mask_output`` if the output is not a dictionary-like object (such as a string).
-            is_classmethod:
-            is_staticmethod:
+                                 Use ``mask_output`` if the output is not a dictionary-like object (such as a string)
+            is_classmethod: If ``True`` then the method is intended to be a classmethod.
+            is_staticmethod: If ``True`` the the method is intended to be a staticmethod.
         """
         log_tag = log_tag or self.default_log_tag
         if isinstance(mask_output_regexes, list):
@@ -786,7 +777,7 @@ class Logger(metaclass=_Singleton):
     def _commit_log(self, msg: Any, log_tag: LogTagBase, file_path: str, line_num: int, func: str = None,
                     force: bool = False, no_console: bool = False, no_persistence: bool = False):
         """
-        Commits the log transaction to the console and the SQLite DB.
+        Commits the log transaction to the console (or redirect stream) and to memory..
 
         Args:
             msg: Log message.
